==> haskell-arch-web-0.2-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-8VQn1xKcljJ9Vm1CrePlP6
key:                  arch-web-0.2-8VQn1xKcljJ9Vm1CrePlP6
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  5d2526b655857bb44a1663ab70458b49
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-8VQn1xKcljJ9Vm1CrePlP6
depends:
    aeson-2.1.2.1-LpT6Mf0v1IAHC9jBcKu3TC base-4.17.2.1
    deriving-aeson-0.2.10-6OITgFUtqlbAdUdGUPaN3S exceptions-0.10.5
    http-client-0.7.17-CKsA30YmMYALZuCSdtq8LI
    http-client-tls-0.3.6.4-8dz8Cr1EoJ9CU6gnshIr0Z
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    lens-5.2.3-1xyXEUn2kF27mSgPIa0sOB mtl-2.2.2
    servant-0.20.2-GVxvSbMoirlASrn7ZNK6r9
    servant-client-0.20-25YOf2jrWotDwsIcAr0N81
    servant-client-core-0.20.2-5HWx69Qi91f1GGQqDEO9ai text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-8HFnWaC82JPayXjaLmiRu
key:                  arch-web-0.2-8HFnWaC82JPayXjaLmiRu
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  41da9fe0bc69210c7a034eef8a8bdb66
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-8HFnWaC82JPayXjaLmiRu
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1
    deriving-aeson-0.2.10-LoTZCkgM6IYAXeC00OGSNS exceptions-0.10.5
    http-client-0.7.17-CKsA30YmMYALZuCSdtq8LI
    http-client-tls-0.3.6.4-8dz8Cr1EoJ9CU6gnshIr0Z
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 mtl-2.2.2
    servant-0.20.2-6rhHHk6IKaj8v8dmAfdnJS
    servant-client-0.20-4Dh3QbPuseGbtAkiXu0wW
    servant-client-core-0.20.2-CKc9udkJ8sEDwMGPvKf0qT text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
